# cs107-FinalProject
Final project deliverables

Group #5
Gregoire Baverez
Xinrong Yang
Aloysius Lim
Shivam Raval

### Broader Impact and Inclusivity Statement

As we design this software, our intention is to contribute to the community, by providing an easier way to perform differentiation. Despite our well-intention, we are conscious that that could be a gap between the real world impacts of our work, and also the way which the computing community view our work. There are definitely downsides of our work, beyond what the software is intended to do.

While it is not our intention, our software inherently discriminates. It assumes that users have a prior knowledge of basic computing, calculus. This discriminates against people who are not literate in computing or not well-versed in calculus. Our content and instructions are in English, which is another form of discrimination against non-English speakers. We recognize that we can address such forms of discriminations by making our software easier to use. This could be the form of developing Graphical-User-Interface so that less computing language is required. We can also develop our software in different languages to cater to people of different backgrounds. Even though these are not addressed yet due to the scale of our project, we recognize the importance of inclusivity.

Our software could also have an impact on the job market, as with every other automation that comes with technology. One may argue that it is to a lesser extent, due to the already prevalent automatic differentiation tools when this software was developed. Nevertheless, the impact should not be ignored. We however design this with the hope that it could be an upskilling resource available to increase the productivity, and employability of workers.

With the recognition of the downsides that our existing software could bring to the wider community, we are taking notes on how we could possibly improve our software at its next possible development stage.



## Badge travisci
[![Build Status](https://app.travis-ci.com/cs107-i-m-i-m/cs107-FinalProject.svg?token=RKxQRxaJdxdtKXuUyQLW&branch=main)](https://app.travis-ci.com/cs107-i-m-i-m/cs107-FinalProject)

## Badge Codecov
[![codecov](https://codecov.io/gh/cs107-i-m-i-m/cs107-FinalProject/branch/main/graph/badge.svg?token=JSLV57IM18)](https://codecov.io/gh/cs107-i-m-i-m/cs107-FinalProject)
